@@ -13,20 +13,30 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #ifndef ENCODER_LAME_H
 #define ENCODER_LAME_H
 
 #include "audiocdencoder.h"
+#include "ui_encoderlameconfig.h"
+
+#include <kprocess.h>
+
+class EncoderLameConfig : public QWidget, public Ui::EncoderLameConfig
+{
+public:
+  EncoderLameConfig( QWidget *parent = 0 ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
 
-class KProcess;
 
 /**
  * MP3 encoder using the LAME encoder.
  * Go to http://lame.sourceforge.net/ for lots of information.
- */
+ */ 
 class EncoderLame : public QObject, public AudioCDEncoder {
 
 Q_OBJECT
@@ -35,25 +45,25 @@ public:
 	EncoderLame(KIO::SlaveBase *slave);
 	~EncoderLame();
 
-	virtual QString type() const { return "MP3"; };
+	virtual QString type() const { return "MP3"; }
 	virtual bool init();
 	virtual void loadSettings();
 	virtual unsigned long size(long time_secs) const;
-	virtual const char * fileType() const { return "mp3"; };
-	virtual const char * mimeType() const { return "audio/x-mp3"; };
+	virtual const char * fileType() const { return "mp3"; }
+	virtual const char * mimeType() const { return "audio/x-mp3"; }
 	virtual void fillSongInfo( KCDDB::CDInfo info, int track, const QString &comment );
 	virtual long readInit(long size);
 	virtual long read(int16_t * buf, int frames);
 	virtual long readCleanup();
 	virtual QString lastErrorMessage() const;
-
+  
 	virtual QWidget* getConfigureWidget(KConfigSkeleton** manager) const;
 
 protected slots:
-	void wroteStdin(KProcess *proc);
-	void receivedStdout(KProcess *, char *buffer, int length);
-	void receivedStderr(KProcess *proc, char *buffer, int buflen);
-	void processExited(KProcess *proc);
+// 	void wroteStdin();
+	void receivedStdout();
+	void receivedStderr();
+	void processExited(int exitCode, QProcess::ExitStatus /*status*/);
 
 private:
 	class Private;
