@@ -32,8 +32,10 @@
 
 #include "core/volume.h"
 class Mixer_Backend;
+#include "core/MasterControl.h"
 #include "mixset.h"
 #include "core/mixdevice.h"
+#include "dbus/dbusmixerwrapper.h"
 
 class Volume;
 class KConfig;
@@ -43,8 +45,19 @@ class Mixer : public QObject
       Q_OBJECT
 
 public:
-    enum MixerError { ERR_PERM=1, ERR_WRITE, ERR_READ,
-        ERR_OPEN, ERR_LASTERR };
+	/**
+	 * Status for Mixer operations.
+	 * 
+	 * OK_UNCHANGED is a apecial variant of OK. It must be implemented by
+	 * backends that use needsPolling() == true. See Mixer_OSS.cpp for an
+	 * example. Rationale is that we need a proper change check: Otherwise
+	 * the DBUS Session Bus is massively spammed. Also quite likely the Mixer
+	 * GUI might get updated all the time.
+	 * 
+	 */
+    enum MixerError { OK=0, ERR_PERM=1, ERR_WRITE, ERR_READ,
+        ERR_OPEN, ERR_LASTERR, OK_UNCHANGED };
+
 
     Mixer( QString& ref_driverName, int device );
     virtual ~Mixer();
@@ -61,7 +74,6 @@ public:
     /// Tells the number of the mixing devices
     unsigned int size() const;
 
-
     /// Returns a pointer to the mix device with the given number
     MixDevice* operator[](int val_i_num);
 
@@ -79,6 +91,9 @@ public:
     /// Close/release the mixer
     virtual int close();
 
+    /// Reads balance
+    int balance() const;
+
     /// Returns a detailed state message after errors. Only for diagnostic purposes, no i18n.
     QString& stateMessage() const;
 
@@ -116,6 +131,10 @@ public:
     // Solaris: /dev/audio
     QString& udi();
 
+    // Returns a DBus path for this mixer
+    // Used also by MixDevice to bind to this path
+    const QString dbusPath();
+
     static QList<Mixer*> & mixers();
 
     /******************************************
@@ -123,11 +142,12 @@ public:
     different MasterCard's at the moment (but actually KMixPanelApplet does not read/save this yet).
     At the moment it is only used for selecting the Mixer to use in KMix's DockIcon.
     ******************************************/
-    static void setGlobalMaster(QString& ref_card, QString& ref_control);
+    static void setGlobalMaster(QString ref_card, QString ref_control, bool preferred);
     static MixDevice* getGlobalMasterMD();
     static MixDevice* getGlobalMasterMD(bool fallbackAllowed);
     static Mixer* getGlobalMasterMixer();
     static Mixer* getGlobalMasterMixerNoFalback();
+    static MasterControl& getGlobalMasterPreferred();
 
     /******************************************
     The recommended master of this Mixer.
@@ -139,29 +159,10 @@ public:
     MixSet getMixSet();
 
 
-    /// DCOP oriented methods (look at mixerIface.h for the descriptions)
-    virtual void setVolume( const QString& mixdeviceID, int percentage );
-    virtual void setAbsoluteVolume( const QString& mixdeviceID, long absoluteVolume );
-    virtual void setMasterVolume( int percentage );
-
+    /// DBUS oriented methods
     virtual void increaseVolume( const QString& mixdeviceID );
     virtual void decreaseVolume( const QString& mixdeviceID );
 
-    virtual long absoluteVolume( const QString& mixdeviceID );
-    virtual long absoluteVolumeMin( const QString& mixdeviceID );
-    virtual long absoluteVolumeMax( const QString& mixdeviceID );
-    virtual int volume( const QString& mixdeviceID );
-    virtual int masterVolume();
-
-    virtual QString masterDeviceIndex();
-
-    virtual void setMute( const QString& mixdeviceID, bool on );
-    virtual bool mute( const QString& mixdeviceID );
-    virtual void toggleMute( const QString& mixdeviceID );
-    virtual bool isRecordSource( const QString& mixdeviceID );
-
-    virtual bool isAvailableDevice( const QString& mixdeviceID );
-
     /// Says if we are dynamic (e.g. widgets can come and go)
     virtual void setDynamic( bool dynamic = true );
     virtual bool isDynamic();
@@ -184,10 +185,6 @@ protected:
     int m_balance; // from -100 (just left) to 100 (just right)
     static QList<Mixer*> s_mixers;
 
-private slots:
-    void controlChangedForwarder();
-    void controlsReconfiguredForwarder(const QString & mixer_ID);
-
 private:
     void setBalanceInternal(Volume& vol);
     void recreateId();
@@ -197,10 +194,9 @@ private:
     QString _id;
     QString _masterDevicePK;
     int    _cardInstance;
-    static QString _globalMasterCard;
-    static QString _globalMasterCardDevice;
+    static MasterControl _globalMasterCurrent;
+    static MasterControl _globalMasterPreferred;
 
-    QString m_dbusName;
     bool m_dynamic;
 };
 
